var QueryClientManager = /** @class */ (function () {
    function QueryClientManager(options) {
        this.queryClient = options.queryClient;
    }
    QueryClientManager.prototype.getQueryCache = function () {
        return this.queryClient.getQueryCache();
    };
    QueryClientManager.prototype.getQueries = function () {
        return this.getQueryCache().getAll();
    };
    QueryClientManager.prototype.getQueryByHash = function (queryHash) {
        return this.getQueries().find(function (query) { return query.queryHash === queryHash; });
    };
    QueryClientManager.prototype.fetchQueryByHash = function (queryHash) {
        var _a;
        return (_a = this.getQueryByHash(queryHash)) === null || _a === void 0 ? void 0 : _a.fetch();
    };
    QueryClientManager.prototype.subscribe = function (callback, mutationCallback) {
        this.queryCacheEvent = this.queryClient.getQueryCache().subscribe(function (_event) {
            // @ts-expect-error - this is a valid event
            callback(_event);
        });
        this.mutationCacheEvent = this.queryClient.getMutationCache().subscribe(function (_event) {
            // @ts-expect-error - this is a valid event
            mutationCallback(_event);
        });
    };
    QueryClientManager.prototype.unsubscribe = function () {
        if (this.queryCacheEvent) {
            this.queryCacheEvent();
            this.queryCacheEvent = undefined;
        }
        if (this.mutationCacheEvent) {
            this.mutationCacheEvent();
            this.mutationCacheEvent = undefined;
        }
    };
    QueryClientManager.prototype.invalidateQueries = function (key) {
        if (key === "") {
            return this.queryClient.invalidateQueries();
        }
        return this.queryClient.invalidateQueries({
            queryKey: [key],
        });
    };
    return QueryClientManager;
}());
export { QueryClientManager };
//# sourceMappingURL=query-client-manager.js.map